@@ -11,8 +11,8 @@
 // the same.
 ////
 
-#ifndef __FOUNTAIN_H__
-#define __FOUNTAIN_H__
+#ifndef FOUNTAIN_H
+#define FOUNTAIN_H
 
 #include <qdialog.h>
 #include <qgl.h>
@@ -26,8 +26,8 @@
 #include <kscreensaver.h>
 #include <qtimer.h>
 #include <qimage.h>
-#include "fountaincfg.h"
-#include <kinstance.h>
+#include "ui_fountaincfg.h"
+#include <kcomponentdata.h>
 #include <qfile.h>
 #include <qtextstream.h>
 
@@ -59,7 +59,7 @@ Q_OBJECT
 	};
 
 public:
-	Fountain( QWidget * parent=0, const char * name=0 );
+	Fountain( QWidget * parent=0 );
 	~Fountain();
 	void setSize( float newSize );
 	void setStars( bool doStars );
@@ -68,7 +68,7 @@ protected:
 	void paintGL ();
 	/** resize the gl view */
 	void resizeGL ( int w, int h );
-	/** setup the GL enviroment */
+	/** setup the GL environment */
 	void initializeGL ();
 
 
@@ -117,11 +117,11 @@ private:
 	QTimer  *timer;
 };
 
-class KFountainSetup : public SetupUi
+class KFountainSetup : public QDialog, public Ui::SetupUi
 {
 	Q_OBJECT
 public:
-	KFountainSetup( QWidget *parent = NULL, const char *name = NULL );
+	KFountainSetup( QWidget *parent =0L);
 
 protected:
 	void readSettings();
