@@ -1,5 +1,5 @@
 /*
-  $Id: icewm.cpp 465369 2005-09-29 14:33:08Z mueller $
+  $Id: icewm.cpp 701437 2007-08-18 09:21:30Z amth $
 
   Gallium-IceWM themeable KWin client
 
@@ -54,6 +54,15 @@
 #include <qstring.h>
 #include <qtooltip.h>
 #include <qregexp.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QPaintEvent>
+#include <QGridLayout>
+#include <QEvent>
+#include <QBoxLayout>
+#include <QShowEvent>
+#include <QResizeEvent>
+#include <QMouseEvent>
 #include "icewm.h"
 
 namespace IceWM {
@@ -240,9 +249,9 @@ void ThemeHandler::readConfig()
 	KConfig conf("kwinicewmrc");
 	conf.setGroup("General");
 	themeName = conf.readEntry("CurrentTheme");
-	themeTitleTextColors = conf.readBoolEntry("ThemeTitleTextColors", true);
-	showMenuButtonIcon = conf.readBoolEntry("ShowMenuButtonIcon", false);
-	titleBarOnTop = conf.readBoolEntry("TitleBarOnTop", true);
+	themeTitleTextColors = conf.readEntry("ThemeTitleTextColors", true);
+	showMenuButtonIcon = conf.readEntry("ShowMenuButtonIcon", false);
+	titleBarOnTop = conf.readEntry("TitleBarOnTop", true);
 
 	customButtonPositions = KDecoration::options()->customButtonPositions();
 	if (customButtonPositions)
@@ -763,7 +772,7 @@ bool ThemeHandler::supports( Ability ability )
 
 IceWMButton::IceWMButton(IceWMClient *parent, const char *name, QPixmap* (*p)[2],
 	  bool isToggle, const QString& tip, const int realizeBtns )
-    : QButton(parent->widget(), name)
+    : Q3Button(parent->widget(), name)
 {
 	m_realizeButtons = realizeBtns;
 	setTipText(tip);
@@ -780,7 +789,7 @@ IceWMButton::IceWMButton(IceWMClient *parent, const char *name, QPixmap* (*p)[2]
 void IceWMButton::setTipText(const QString &tip) {
 	if(KDecoration::options()->showTooltips()) {
 		QToolTip::remove(this );
-		QToolTip::add(this, tip );
+		this->setToolTip( tip );
 	}
 }
 
@@ -840,8 +849,8 @@ void IceWMButton::mousePressEvent( QMouseEvent* e )
 {
 	last_button = e->button();
 	QMouseEvent me ( e->type(), e->pos(), e->globalPos(),
-					 (e->button()&m_realizeButtons)?LeftButton:NoButton, e->state() );
-	QButton::mousePressEvent( &me );
+					 (e->button()&m_realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
+	Q3Button::mousePressEvent( &me );
 }
 
 
@@ -849,8 +858,8 @@ void IceWMButton::mouseReleaseEvent( QMouseEvent* e )
 {
 	last_button = e->button();
 	QMouseEvent me ( e->type(), e->pos(), e->globalPos(),
-					 (e->button()&m_realizeButtons)?LeftButton:NoButton, e->state() );
-	QButton::mouseReleaseEvent( &me );
+					 (e->button()&m_realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
+	Q3Button::mouseReleaseEvent( &me );
 }
 
 
@@ -973,7 +982,7 @@ void IceWMClient::addClientButtons( const QString& s )
 						if (showMenuButtonIcon) {
 							renderMenuIcons();
 							button[BtnSysMenu] = new IceWMButton(this, "menu",
-								&menuButtonWithIconPix, false, i18n("Menu"), LeftButton|RightButton);
+								&menuButtonWithIconPix, false, i18n("Menu"), Qt::LeftButton|Qt::RightButton);
 						}
 						else
 							button[BtnSysMenu] = new IceWMButton(this, "menu",
@@ -1002,7 +1011,7 @@ void IceWMClient::addClientButtons( const QString& s )
 					if ( validPixmaps(maximizePix) && !button[BtnMaximize] && isMaximizable() )
 					{
 						button[BtnMaximize] = new IceWMButton(this, "maximize",
-								&maximizePix, false, i18n("Maximize"), LeftButton|MidButton|RightButton);
+								&maximizePix, false, i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
 						hb->addWidget( button[BtnMaximize] );
 						connect( button[BtnMaximize], SIGNAL(clicked()),
 								 this, SLOT(slotMaximize()));
@@ -1078,7 +1087,7 @@ QSpacerItem* IceWMClient::addPixmapSpacer( QPixmap* p[], QSizePolicy::SizeType s
 
 void IceWMClient::renderMenuIcons()
 {
-	QPixmap miniIcon( icon().pixmap( QIconSet::Small, QIconSet::Normal) );
+	QPixmap miniIcon( icon().pixmap( QIcon::Small, QIcon::Normal) );
 
 	if (!miniIcon.isNull())
 	         for(int i = 0; i < 2; i++) {
@@ -1175,10 +1184,10 @@ void IceWMClient::resizeEvent( QResizeEvent* e )
 		int dy = 0;
 
 		if ( e->oldSize().width() != widget()->width() )
-			dx = 32 + QABS( e->oldSize().width() -  width() );
+			dx = 32 + qAbs( e->oldSize().width() -  width() );
 
 		if ( e->oldSize().height() != height() )
-			dy = 8 + QABS( e->oldSize().height() -  height() );
+			dy = 8 + qAbs( e->oldSize().height() -  height() );
 
 		if ( dy )
 			widget()->update( 0, height() - dy + 1, width(), dy );
@@ -1453,7 +1462,7 @@ void IceWMClient::showEvent(QShowEvent *ev)
 
 void IceWMClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-	if( e->button() != LeftButton )
+	if( e->button() != Qt::LeftButton )
 		return;
 
 	QRect r;
